#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_FACT_4_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_FACT_4_HPP_INCLUDED

#include <boost/simd/constant/include/constants/fact_4.hpp>

#endif
